discrete_fourier_sin_cos
discrete_fourier_sin_cos(x, a, b, tau)Fourier approximation or vector of Fourier approximations evaluated in x
argument for which the acf will be computed (this can be a vector)
vector of coefficients a_0,...a_n
vector of coefficients b_1,...b_n
period of function
Computes the Fourier approximation of a function using the sin-cos representation for given coefficients a_0,...a_n, b_1, ...b_n and rounds the values to a grid of width 1