Learn R Programming

ambit (version 0.2.3)

fit_LM_periodic_trawl: Fits a supGamma periodic trawl function to equidistant time series data

Description

Fits a supGamma periodic trawl function to equidistant time series data

Usage

fit_LM_periodic_trawl(
  x,
  m = 1,
  tau,
  GMMlag = 50,
  Delta = 1,
  plotacf = FALSE,
  lags = 100
)

Value

alpha: the parameter \(\alpha\) in the supGamma trawl, H: the parameter \(H\) in the supGamma trawl, tau: the period \(\tau\), a: the vector of the Fourier coefficients, b: the vector of the Fourier coefficients.

Arguments

x

vector of equidistant time series data

m

the order of the Fourier approximation of the periodic function

tau

the period, if not provided it will be estimated

GMMlag

lag length used in the GMM estimation, the default is 50

Delta

interval length of the time grid used in the time series, the default is 1

plotacf

binary variable specifying whether or not the empirical and fitted autocorrelation function should be plotted

lags

number of lags to be used in the plot of the autocorrelation function

Details

The trawl function is parametrised by the parameter \(\lambda > 0\) as follows: $$g(x) = (1+x/\alpha)^H, \mbox{ for } x \le 0.$$ The parameter \(\tau\) is estimated using the smoothed periodogram, the other parameters are estimated by GMM.