Learn R Programming

ambit (version 0.2.3)

kernel_trawl_acf_exp_periodic: kernel_trawl_acf_exp_periodic

Description

kernel_trawl_acf_exp_periodic

Usage

kernel_trawl_acf_exp_periodic(x, lambda, a, b, tau)

Value

acf or vector of acfs evaluated in x

Arguments

x

argument for which the acf will be computed (this can be a vector)

lambda

parameter in the trawl function

a

vector of Fourier coefficients

b

vector of Fourier coefficients

tau

period in the sine function

Details

We compute the acf of a weighted trawl process with exponential trawl function and periodic function