Learn R Programming

ambit (version 0.1.2)

my_results: my_results

Description

Returns summary statistics

Usage

my_results(x, sd = 1, digits = 3)

Value

The vector of the sample mean, sample standard deviation and the coverage probabilities at level 75%, 80%, 85%, 90%, 95%, 99% compared to the standard normal quantiles.

Arguments

x

data

sd

Optional parameter giving the standard deviation of the normal distribution used for computing the coverage probabilities

digits

Optional parameter to how many digits the results should be rounded, the default is three.

Details

This functions returns the sample mean, sample standard deviation and the coverage probabilities at level 75%, 80%, 85%, 90%, 95%, 99% compared to the standard normal quantiles.

Examples

Run this code
#Simulate i.i.d.~standard normal data
set.seed(456)
data <- rnorm(10000)
#Display the sample mean, standard deviation and coverage probabilities:
my_results(data)

Run the code above in your browser using DataLab