The vector of the sample mean, sample standard deviation
and the coverage probabilities at level 75%, 80%, 85%, 90%, 95%, 99%
compared to the standard normal quantiles.
Arguments
x
data
sd
Optional parameter giving the standard deviation of the normal
distribution used for computing the coverage probabilities
digits
Optional parameter to how many digits the results
should be rounded, the default is three.
Details
This functions returns the sample mean, sample standard deviation
and the coverage probabilities at level 75%, 80%, 85%, 90%, 95%, 99%
compared to the standard normal quantiles.
#Simulate i.i.d.~standard normal dataset.seed(456)
data <- rnorm(10000)
#Display the sample mean, standard deviation and coverage probabilities:my_results(data)